@@ -5,22 +5,22 @@
    Tyrell ConfigSection
 
    File     : ConfigSection.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/ConfigSection.cpp $
-   
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
+
    Copyright notice:
 
     This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License  
+    modify it under the terms of the GNU General Public License
     as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
-   
+
     This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of 
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-   
+
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
@@ -49,7 +49,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: ConfigSection.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /*------------------------------------------------------------------------------
@@ -68,7 +68,7 @@ static const char fileid[] = "$Id: ConfigSection.cpp 553 2013-07-15 05:50:56Z ra
  *----------------------------------------------------------------------------*/
 bool
 ConfigSection :: add (   const char    * key,
-                         const char    * value )            throw ( Exception )
+                         const char    * value )
 {
     if ( !key || !value ) {
         throw Exception( __FILE__, __LINE__, "no key or value");
@@ -81,13 +81,13 @@ ConfigSection :: add (   const char    * key,
 
     return res.second;
 }
-        
-        
+
+
 /*------------------------------------------------------------------------------
  *  Get a value for a key
  *----------------------------------------------------------------------------*/
 const char *
-ConfigSection :: get (  const char    * key ) const         throw ( Exception )
+ConfigSection :: get (  const char    * key ) const
 {
     if ( !key ) {
         throw Exception( __FILE__, __LINE__, "no key");
@@ -109,10 +109,9 @@ ConfigSection :: getForSure (   const char    * key,
                                 const char    * message1,
                                 const char    * message2,
                                 int             code ) const
-                                                        throw ( Exception )
 {
     const char      * value;
-    
+
     if ( !(value = get( key)) ) {
         throw Exception( __FILE__, __LINE__, key, message1, message2, code);
     }
@@ -125,19 +124,23 @@ ConfigSection :: getForSure (   const char    * key,
  *  Add a configuration line
  *----------------------------------------------------------------------------*/
 bool
-ConfigSection :: addLine (  const char    * line )          throw ( Exception )
+ConfigSection :: addLine (  const char    * line )
 {
     if ( !line ) {
         throw Exception( __FILE__, __LINE__, "no line");
     }
 
     std::string::size_type  ix;
-    std::string             str( line);
+    std::string str( line);
+    std::string str2 ("password");
 
-    /* delete everything after the first # */
-    if ( (ix = str.find( '#')) != str.npos ) {
-        str.erase( ix);
+    if ( (ix = str.find(str2)) == str.npos ) {
+        /* delete everything after the first # */
+           if ( (ix = str.find( '#')) != str.npos ) {
+              str.erase( ix);
+            }
     }
+
     /* eat up all white space from the front */
     if ( (ix = str.find_first_not_of( WHITE_SPACE_STR)) != str.npos ) {
         str.erase( 0, ix);
@@ -170,4 +173,3 @@ ConfigSection :: addLine (  const char    * line )          throw ( Exception )
     /* now add the new key / value pair */
     return add( key.c_str(), value.c_str());
 }
-
