@@ -8,20 +8,20 @@
    Version  : $Revision$
    Author   : $Author$
    Location : $HeadURL$
-   
+
 
    Copyright notice:
 
     This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License  
+    modify it under the terms of the GNU General Public License
     as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
-   
+
     This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of 
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-   
+
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
@@ -96,6 +96,10 @@
 #include "OpusLibEncoder.h"
 #endif
 
+#ifdef HAVE_FLAC_LIB
+#include "FlacLibEncoder.h"
+#endif
+
 #ifdef HAVE_FAAC_LIB
 #include "FaacEncoder.h"
 #endif
@@ -137,7 +141,7 @@ static const char fileid[] = "$Id$";
  *  Initialize the object
  *----------------------------------------------------------------------------*/
 void
-DarkIce :: init ( const Config      & config )              throw ( Exception )
+DarkIce :: init ( const Config      & config )              
 {
     unsigned int             bufferSecs;
     const ConfigSection    * cs;
@@ -214,7 +218,7 @@ DarkIce :: init ( const Config      & config )              throw ( Exception )
 void
 DarkIce :: configIceCast (  const Config      & config,
                             unsigned int        bufferSecs  )
-                                                        throw ( Exception )
+                                                        
 {
     // look for IceCast encoder output streams,
     // sections [icecast-0], [icecast-1], ...
@@ -384,9 +388,9 @@ DarkIce :: configIceCast (  const Config      & config,
                              "unsupported stream format: ", str);
 
         }
-        
+
         // augment audio outs with a buffer when used from encoder
-        audioOut = new BufferedSink( audioOuts[u].server.get(), 
+        audioOut = new BufferedSink( audioOuts[u].server.get(),
                                                   bufferSize, 1);
 
 #ifdef HAVE_LAME_LIB
@@ -428,7 +432,7 @@ DarkIce :: configIceCast (  const Config      & config,
 void
 DarkIce :: configIceCast2 (  const Config      & config,
                              unsigned int        bufferSecs  )
-                                                        throw ( Exception )
+                                                        
 {
     // look for IceCast2 encoder output streams,
     // sections [icecast2-0], [icecast2-1], ...
@@ -457,6 +461,7 @@ DarkIce :: configIceCast2 (  const Config      & config,
         double                      quality         = 0.0;
         const char                * server          = 0;
         unsigned int                port            = 0;
+        const char                * username        = 0;
         const char                * password        = 0;
         const char                * mountPoint      = 0;
         const char                * name            = 0;
@@ -466,6 +471,7 @@ DarkIce :: configIceCast2 (  const Config      & config,
         bool                        isPublic        = false;
         int                         lowpass         = 0;
         int                         highpass        = 0;
+        unsigned int                compression     = 0;
         const char                * localDumpName   = 0;
         FileSink                  * localDumpFile   = 0;
         bool                        fileAddDate     = false;
@@ -478,6 +484,8 @@ DarkIce :: configIceCast2 (  const Config      & config,
             format = IceCast2::oggVorbis;
         } else if ( Util::strEq( str, "opus") ) {
             format = IceCast2::oggOpus;
+        } else if ( Util::strEq( str, "flac") ) {
+            format = IceCast2::oggFlac;
         } else if ( Util::strEq( str, "mp3") ) {
             format = IceCast2::mp3;
         } else if ( Util::strEq( str, "mp2") ) {
@@ -537,6 +545,8 @@ DarkIce :: configIceCast2 (  const Config      & config,
         str         = cs->getForSure( "port", " missing in section ", stream);
         port        = Util::strToL( str);
         password    = cs->getForSure("password"," missing in section ",stream);
+        username    = cs->get("username");
+        username    = (username != NULL) ? username : "source";
         mountPoint  = cs->getForSure( "mountPoint",
                                       " missing in section ",
                                       stream);
@@ -550,6 +560,8 @@ DarkIce :: configIceCast2 (  const Config      & config,
         lowpass     = str ? Util::strToL( str) : 0;
         str         = cs->get( "highpass");
         highpass    = str ? Util::strToL( str) : 0;
+        str         = cs->get( "compression");
+        compression = str ? Util::strToL( str) : 5;
         str         = cs->get( "fileAddDate");
         fileAddDate = str ? (Util::strEq( str, "yes") ? true : false) : false;
         fileDateFormat = cs->get( "fileDateFormat");
@@ -589,6 +601,7 @@ DarkIce :: configIceCast2 (  const Config      & config,
         // streaming related stuff
         audioOuts[u].socket = new TcpSocket( server, port);
         audioOuts[u].server = new IceCast2( audioOuts[u].socket.get(),
+                                            username,
                                             password,
                                             mountPoint,
                                             format,
@@ -600,9 +613,9 @@ DarkIce :: configIceCast2 (  const Config      & config,
                                             isPublic,
                                             localDumpFile);
 
-        audioOut = new BufferedSink( audioOuts[u].server.get(), 
+        audioOut = new BufferedSink( audioOuts[u].server.get(),
                                      bufferSize, 1);
-        
+
         switch ( format ) {
             case IceCast2::mp3:
 #ifndef HAVE_LAME_LIB
@@ -668,6 +681,27 @@ DarkIce :: configIceCast2 (  const Config      & config,
 #endif // HAVE_OPUS_LIB
                 break;
 
+            case IceCast2::oggFlac:
+#ifndef HAVE_FLAC_LIB
+                throw Exception( __FILE__, __LINE__,
+                                "DarkIce not compiled with Ogg FLAC support, "
+                                "thus can't Ogg FLAC stream: ",
+                                stream);
+#else
+
+                audioOuts[u].encoder = new FlacLibEncoder(
+                                               audioOut,
+                                               dsp.get(),
+                                               bitrateMode,
+                                               bitrate,
+                                               quality,
+                                               sampleRate,
+                                               dsp->getChannel(),
+                                               compression);
+
+#endif // HAVE_FLAC_LIB
+                break;
+
             case IceCast2::mp2:
 #ifndef HAVE_TWOLAME_LIB
                 throw Exception( __FILE__, __LINE__,
@@ -743,7 +777,7 @@ DarkIce :: configIceCast2 (  const Config      & config,
 void
 DarkIce :: configShoutCast (    const Config      & config,
                                 unsigned int        bufferSecs  )
-                                                        throw ( Exception )
+                                                        
 {
     // look for Shoutcast encoder output streams,
     // sections [shoutcast-0], [shoutcast-1], ...
@@ -792,7 +826,7 @@ DarkIce :: configShoutCast (    const Config      & config,
         FileSink                  * localDumpFile   = 0;
         bool                        fileAddDate     = false;
         const char                * fileDateFormat  = 0;
-        BufferedSink              * audioOut        = 0;
+        AudioEncoder              * encoder         = 0;
         int                         bufferSize      = 0;
 
         str         = cs->get( "sampleRate");
@@ -907,9 +941,7 @@ DarkIce :: configShoutCast (    const Config      & config,
                                              localDumpFile);
 
 
-        audioOut = new BufferedSink(audioOuts[u].socket.get(), bufferSize, 1);
-        audioOuts[u].encoder = new LameLibEncoder( 
-                                      audioOut,
+        encoder = new LameLibEncoder( audioOuts[u].server.get(),
                                       dsp.get(),
                                       bitrateMode,
                                       bitrate,
@@ -918,6 +950,7 @@ DarkIce :: configShoutCast (    const Config      & config,
                                       channel,
                                       lowpass,
                                       highpass );
+        audioOuts[u].encoder = new BufferedSink(encoder, bufferSize, dsp->getSampleSize());
 
         encConnector->attach( audioOuts[u].encoder.get());
 #endif // HAVE_LAME_LIB
@@ -932,7 +965,7 @@ DarkIce :: configShoutCast (    const Config      & config,
  *----------------------------------------------------------------------------*/
 void
 DarkIce :: configFileCast (  const Config      & config )
-                                                        throw ( Exception )
+                                                        
 {
     // look for FileCast encoder output streams,
     // sections [file-0], [file-1], ...
@@ -1176,7 +1209,7 @@ DarkIce :: configFileCast (  const Config      & config )
  *  Set POSIX real-time scheduling
  *----------------------------------------------------------------------------*/
 void
-DarkIce :: setRealTimeScheduling ( void )               throw ( Exception )
+DarkIce :: setRealTimeScheduling ( void )               
 {
 // Only if the OS has the POSIX real-time scheduling functions implemented.
 #if defined( HAVE_SCHED_GETSCHEDULER ) && defined( HAVE_SCHED_GETPARAM )
@@ -1233,7 +1266,7 @@ DarkIce :: setRealTimeScheduling ( void )               throw ( Exception )
  *  WARNING: make sure you don't call this before setRealTimeScheduling!!
  *----------------------------------------------------------------------------*/
 void
-DarkIce :: setOriginalScheduling ( void )               throw ( Exception )
+DarkIce :: setOriginalScheduling ( void )               
 {
 // Only if the OS has the POSIX real-time scheduling functions implemented.
 #if defined( HAVE_SCHED_GETSCHEDULER ) && defined( HAVE_SCHED_GETPARAM )
@@ -1264,7 +1297,7 @@ DarkIce :: setOriginalScheduling ( void )               throw ( Exception )
  *  Run the encoder
  *----------------------------------------------------------------------------*/
 bool
-DarkIce :: encode ( void )                          throw ( Exception )
+DarkIce :: encode ( void )                          
 {
     unsigned int       len;
     unsigned long      bytes;
@@ -1289,7 +1322,7 @@ DarkIce :: encode ( void )                          throw ( Exception )
  *  Run
  *----------------------------------------------------------------------------*/
 int
-DarkIce :: run ( void )                             throw ( Exception )
+DarkIce :: run ( void )                             
 {
     reportEvent( 3, "encoding");
 
