@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : Exception.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/Exception.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -51,7 +51,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: Exception.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /* ===============================================  local function prototypes */
