@@ -7,9 +7,9 @@
    Tyrell DarkIce
 
    File     : JackDspSource.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/JackDspSource.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -82,6 +82,12 @@
 #error need limits.h
 #endif
 
+#ifdef HAVE_STDIO_H
+#include <stdio.h>
+#endif
+
+#include <climits>
+
 #include "Util.h"
 #include "Exception.h"
 #include "JackDspSource.h"
@@ -95,7 +101,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: JackDspSource.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /* ===============================================  local function prototypes */
@@ -107,7 +113,7 @@ static const char fileid[] = "$Id: JackDspSource.cpp 553 2013-07-15 05:50:56Z ra
  *  Initialize the object
  *----------------------------------------------------------------------------*/
 void
-JackDspSource :: init ( const char* name )           throw ( Exception )
+JackDspSource :: init ( const char* name )           
 {
     // Set defaults
     ports[0]     = NULL;        // Left Port
@@ -136,7 +142,7 @@ JackDspSource :: init ( const char* name )           throw ( Exception )
  *  De-initialize the object
  *----------------------------------------------------------------------------*/
 void
-JackDspSource :: strip ( void )                      throw ( Exception )
+JackDspSource :: strip ( void )                      
 {
     if ( isOpen() ) {
         close();
@@ -155,7 +161,7 @@ JackDspSource :: strip ( void )                      throw ( Exception )
  *   - Just connect left&right to the first two output ports we find
  *----------------------------------------------------------------------------*/
 void
-JackDspSource :: do_auto_connect ( void )                   throw ( Exception )
+JackDspSource :: do_auto_connect ( void )                   
 {
     const char **all_ports;
     unsigned int ch = 0;
@@ -195,7 +201,7 @@ JackDspSource :: do_auto_connect ( void )                   throw ( Exception )
  *  Open the audio source
  *----------------------------------------------------------------------------*/
 bool
-JackDspSource :: open ( void )                       throw ( Exception )
+JackDspSource :: open ( void )                       
 {
     char         client_name[255];
     size_t       rb_size;
@@ -296,11 +302,11 @@ JackDspSource :: open ( void )                       throw ( Exception )
 
 
 /*------------------------------------------------------------------------------
- *  Check wether read() would return anything
+ *  Check whether read() would return anything
  *----------------------------------------------------------------------------*/
 bool
 JackDspSource :: canRead ( unsigned int   sec,
-                           unsigned int   usec )    throw ( Exception )
+                           unsigned int   usec )    
 {
     const unsigned int max_wait_time  = sec * 1000000;
     const unsigned int wait_increment = 10000;
@@ -343,7 +349,7 @@ JackDspSource :: canRead ( unsigned int   sec,
  *----------------------------------------------------------------------------*/
 unsigned int
 JackDspSource :: read (   void          * buf,
-                          unsigned int    len )     throw ( Exception )
+                          unsigned int    len )     
 {
     jack_nframes_t samples         = len / 2 / getChannel();
     jack_nframes_t samples_read[2] = { 0, 0 };
@@ -410,7 +416,7 @@ JackDspSource :: read (   void          * buf,
  *  Close the audio source
  *----------------------------------------------------------------------------*/
 void
-JackDspSource :: close ( void )                  throw ( Exception )
+JackDspSource :: close ( void )                  
 {
     unsigned int i;
 
