@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : LameLibEncoder.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/LameLibEncoder.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -51,7 +51,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: LameLibEncoder.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /* ===============================================  local function prototypes */
@@ -64,7 +64,7 @@ static const char fileid[] = "$Id: LameLibEncoder.cpp 553 2013-07-15 05:50:56Z r
  *----------------------------------------------------------------------------*/
 bool
 LameLibEncoder :: open ( void )
-                                                            throw ( Exception )
+                                                            
 {
     if ( isOpen() ) {
         close();
@@ -275,7 +275,7 @@ LameLibEncoder :: open ( void )
  *----------------------------------------------------------------------------*/
 unsigned int
 LameLibEncoder :: write (   const void    * buf,
-                            unsigned int    len )           throw ( Exception )
+                            unsigned int    len )           
 {
     if ( !isOpen() || len == 0 ) {
         return 0;
@@ -349,7 +349,7 @@ LameLibEncoder :: write (   const void    * buf,
  *----------------------------------------------------------------------------*/
 void
 LameLibEncoder :: flush ( void )
-                                                            throw ( Exception )
+                                                            
 {
     if ( !isOpen() ) {
         return;
@@ -380,7 +380,7 @@ LameLibEncoder :: flush ( void )
  *  Close the encoding session
  *----------------------------------------------------------------------------*/
 void
-LameLibEncoder :: close ( void )                    throw ( Exception )
+LameLibEncoder :: close ( void )                    
 {
     if ( isOpen() ) {
         flush();
