@@ -5,9 +5,9 @@
    Tyrell Reporter
 
    File     : Reporter.cpp
-   Version  : $Revision: 553 $
-   Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/Reporter.cpp $
+   Version  : $Revision$
+   Author   : $Author$
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -42,7 +42,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: Reporter.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
+static const char fileid[] = "$Id$";
 
 
 /*------------------------------------------------------------------------------
