@@ -114,7 +114,7 @@ static const char fileid[] = "$Id$";
  *----------------------------------------------------------------------------*/
 void
 TcpSocket :: init (   const char    * host,
-                      unsigned short  port )          throw ( Exception )
+                      unsigned short  port )          
 {
     this->host   = Util::strDup( host);
     this->port   = port;
@@ -126,7 +126,7 @@ TcpSocket :: init (   const char    * host,
  *  De-initialize the object
  *----------------------------------------------------------------------------*/
 void
-TcpSocket :: strip ( void)                           throw ( Exception )
+TcpSocket :: strip ( void)                           
 {
     if ( isOpen() ) {
         close();
@@ -139,7 +139,7 @@ TcpSocket :: strip ( void)                           throw ( Exception )
 /*------------------------------------------------------------------------------
  *  Copy Constructor
  *----------------------------------------------------------------------------*/
-TcpSocket :: TcpSocket (  const TcpSocket &    ss )    throw ( Exception )
+TcpSocket :: TcpSocket (  const TcpSocket &    ss )    
                 : Source( ss), Sink( ss )
 {
     int     fd;
@@ -159,7 +159,7 @@ TcpSocket :: TcpSocket (  const TcpSocket &    ss )    throw ( Exception )
  *  Assignment operator
  *----------------------------------------------------------------------------*/
 TcpSocket &
-TcpSocket :: operator= (  const TcpSocket &    ss )   throw ( Exception )
+TcpSocket :: operator= (  const TcpSocket &    ss )   
 {
     if ( this != &ss ) {
         int     fd;
@@ -190,12 +190,12 @@ TcpSocket :: operator= (  const TcpSocket &    ss )   throw ( Exception )
  *  Open the file
  *----------------------------------------------------------------------------*/
 bool
-TcpSocket :: open ( void )                       throw ( Exception )
+TcpSocket :: open ( void )                       
 {
     int                     optval;
     socklen_t               optlen;
-#ifdef HAVE_ADDRINFO
-    struct addrinfo         hints
+#ifdef HAVE_GETADDRINFO
+    struct addrinfo         hints;
     struct addrinfo       * ptr;
     struct sockaddr_storage addr;
     char                    portstr[6];
@@ -208,31 +208,31 @@ TcpSocket :: open ( void )                       throw ( Exception )
         return false;
     }
 
-#ifdef HAVE_ADDRINFO
+#ifdef HAVE_GETADDRINFO
     memset(&hints, 0, sizeof(hints));
     hints.ai_socktype = SOCK_STREAM;
-    hints.ai_family = AF_ANY;
+    hints.ai_family = AF_UNSPEC;
     snprintf(portstr, sizeof(portstr), "%d", port);
 
     if (getaddrinfo(host , portstr, &hints, &ptr)) {
         sockfd = 0;
         throw Exception( __FILE__, __LINE__, "getaddrinfo error", errno);
     }
-    memcpy ( addr, ptr->ai_addr, ptr->ai_addrlen);
+    memcpy ( &addr, ptr->ai_addr, ptr->ai_addrlen);
     freeaddrinfo(ptr);
 #else
     if ( !(pHostEntry = gethostbyname( host)) ) {
         sockfd = 0;
         throw Exception( __FILE__, __LINE__, "gethostbyname error", errno);
     }
-    
+
     memset( &addr, 0, sizeof(addr));
     addr.sin_family      = AF_INET;
     addr.sin_port        = htons(port);
     addr.sin_addr.s_addr = *((long*) pHostEntry->h_addr_list[0]);
 #endif
 
-    if ( (sockfd = socket( AF_INET, SOCK_STREAM,  IPPROTO_TCP)) == -1 ) {
+    if ( (sockfd = socket( addr.ss_family, SOCK_STREAM,  IPPROTO_TCP)) == -1 ) {
         sockfd = 0;
         throw Exception( __FILE__, __LINE__, "socket error", errno);
     }
@@ -240,12 +240,25 @@ TcpSocket :: open ( void )                       throw ( Exception )
     // set TCP keep-alive
     optval = 1;
     optlen = sizeof(optval);
-    if (setsockopt(sockfd, SOL_SOCKET, SO_KEEPALIVE, &optval, optlen) == -1) {  
+    if (setsockopt(sockfd, SOL_SOCKET, SO_KEEPALIVE, &optval, optlen) == -1) {
         reportEvent(5, "can't set TCP socket keep-alive mode", errno);
     }
 
     // connect
-    if ( connect( sockfd, (struct sockaddr*)&addr, sizeof(addr)) == -1 ) {
+    socklen_t addrlen;
+    switch (addr.ss_family) {
+        case AF_INET:
+            addrlen = sizeof(struct sockaddr_in);
+            break;
+        case AF_INET6:
+            addrlen = sizeof(struct sockaddr_in6);
+            break;
+        default:
+            throw Exception( __FILE__, __LINE__, "invalid address family", errno);
+    }
+
+
+    if ( connect( sockfd, (struct sockaddr*)&addr, addrlen) == -1 ) {
         ::close( sockfd);
         sockfd = 0;
         throw Exception( __FILE__, __LINE__, "connect error", errno);
@@ -260,7 +273,7 @@ TcpSocket :: open ( void )                       throw ( Exception )
  *----------------------------------------------------------------------------*/
 bool
 TcpSocket :: canRead (      unsigned int    sec,
-                            unsigned int    usec )      throw ( Exception )
+                            unsigned int    usec )      
 {
     fd_set              fdset;
     struct timespec     timespec;
@@ -298,7 +311,7 @@ TcpSocket :: canRead (      unsigned int    sec,
  *----------------------------------------------------------------------------*/
 unsigned int
 TcpSocket :: read (     void          * buf,
-                        unsigned int    len )       throw ( Exception )
+                        unsigned int    len )       
 {
     int         ret;
 
@@ -333,7 +346,7 @@ TcpSocket :: read (     void          * buf,
  *----------------------------------------------------------------------------*/
 bool
 TcpSocket :: canWrite (    unsigned int    sec,
-                           unsigned int    usec )      throw ( Exception )
+                           unsigned int    usec )      
 {
     fd_set              fdset;
     struct timespec     timespec;
@@ -371,7 +384,7 @@ TcpSocket :: canWrite (    unsigned int    sec,
  *----------------------------------------------------------------------------*/
 unsigned int
 TcpSocket :: write (    const void    * buf,
-                        unsigned int    len )       throw ( Exception )
+                        unsigned int    len )       
 {
     int         ret;
 
@@ -404,7 +417,7 @@ TcpSocket :: write (    const void    * buf,
  *  Close the socket
  *----------------------------------------------------------------------------*/
 void
-TcpSocket :: close ( void )                          throw ( Exception )
+TcpSocket :: close ( void )                          
 {
     if ( !isOpen() ) {
         return;
