@@ -64,7 +64,6 @@ static const char fileid[] = "$Id$";
  *----------------------------------------------------------------------------*/
 bool
 aacPlusEncoder :: open ( void )
-                                                            throw ( Exception )
 {
     if ( isOpen() ) {
         close();
@@ -135,7 +134,7 @@ aacPlusEncoder :: open ( void )
  *----------------------------------------------------------------------------*/
 unsigned int
 aacPlusEncoder :: write (  const void    * buf,
-                        unsigned int    len )           throw ( Exception )
+                        unsigned int    len )
 {
     if ( !isOpen() || len == 0) {
         return 0;
@@ -155,7 +154,7 @@ aacPlusEncoder :: write (  const void    * buf,
     if ( converter ) {
         unsigned int         converted;
 #ifdef HAVE_SRC_LIB
-        src_short_to_float_array ((short *) b, converterData.data_in, samples);
+        src_short_to_float_array ((short *) b, (float *) converterData.data_in, samples);
         converterData.input_frames   = nSamples;
         converterData.data_out = resampledOffset + (resampledOffsetSize * channels);
         int srcError = src_process (converter, &converterData);
@@ -248,7 +247,6 @@ aacPlusEncoder :: write (  const void    * buf,
  *----------------------------------------------------------------------------*/
 void
 aacPlusEncoder :: flush ( void )
-                                                            throw ( Exception )
 {
     if ( !isOpen() ) {
         return;
@@ -262,7 +260,7 @@ aacPlusEncoder :: flush ( void )
  *  Close the encoding session
  *----------------------------------------------------------------------------*/
 void
-aacPlusEncoder :: close ( void )                           throw ( Exception )
+aacPlusEncoder :: close ( void )
 {
     if ( isOpen() ) {
         flush();
